@@ -1,10 +1,18 @@
 import inspect
+import os
 from typing import Any, Callable, Dict, List, Literal, Optional, Union
 
 from motion.dicts import Params
+from motion.discard_policy import DiscardPolicy, validate_policy
 from motion.instance import ComponentInstance
 from motion.route import Route
-from motion.utils import DEFAULT_KEY_TTL, random_passphrase, validate_args
+from motion.utils import (
+    DEFAULT_KEY_TTL,
+    clear_dev_instances,
+    import_config,
+    random_passphrase,
+    validate_args,
+)
 
 
 class Component:
@@ -38,7 +46,7 @@ class Component:
             # Resulting state will eventually be {"value": 3}
         ```
 
-    === "Multiple Dataflows"
+    === "Multiple Flows"
         ```python
         from motion import Component
 
@@ -300,10 +308,10 @@ class Component:
         return func
 
     def serve(self, keys: Union[str, List[str]]) -> Callable:
-        """Decorator for any serve operation for a dataflow through the
+        """Decorator for any serve operation for a flow through the
         component. Takes in a string or list of strings that represents the
-        dataflow key. If the decorator is called with a list of strings, each
-        dataflow key will be mapped to the same serve function.
+        flow key. If the decorator is called with a list of strings, each
+        flow key will be mapped to the same serve function.
 
         2 arguments required for an serve operation:
             * `state`: The current state of the component instance, which is a
@@ -312,10 +320,10 @@ class Component:
                 the `run` method of the component instance. You can add to
                 the `props` dictionary in the serve op, and the modified
                 `props` will be passed to the subsequent update ops in the flow.
-                Props are short-lived and die after the dataflow's update op
+                Props are short-lived and die after the flow's update op
                 finishes.
 
-        Components can have multiple serve ops, but no dataflow key within
+        Components can have multiple serve ops, but no flow key within
         the component can have more than one serve op. serve ops should not
         modify the state object. If you want to modify the state object, write
         an `update` op for your flow.
@@ -345,7 +353,7 @@ class Component:
 
         Args:
             keys (Union[str, List[str]]): String or list of strings that
-                represent the input keyword(s) for the serve dataflow.
+                represent the input keyword(s) for the serve flow.
 
         Returns:
             Callable: Decorated serve function.
@@ -355,9 +363,7 @@ class Component:
 
         for key in keys:
             if "::" in key:
-                raise ValueError(
-                    f"Dataflow key {key} should not have a double colon (::)"
-                )
+                raise ValueError(f"Flow key {key} should not have a double colon (::)")
 
         def decorator(func: Callable) -> Any:
             # type_hint = get_type_hints(func).get("value", None)
@@ -376,11 +382,16 @@ class Component:
 
         return decorator
 
-    def update(self, keys: Union[str, List[str]]) -> Any:
-        """Decorator for any update operations for dataflows through the
+    def update(
+        self,
+        keys: Union[str, List[str]],
+        discard_policy: DiscardPolicy = DiscardPolicy.NONE,
+        discard_after: Optional[int] = None,
+    ) -> Any:
+        """Decorator for any update operations for flows through the
         component. Takes in a string or list of strings that represents the
-        dataflow key. If the decorator is called with a list of strings, each
-        dataflow key will be mapped to the same update operation.
+        flow key. If the decorator is called with a list of strings, each
+        flow key will be mapped to the same update operation.
 
         2 arguments required for a update operation:
             - `state`: The current state of the component, represented as a
@@ -388,12 +399,15 @@ class Component:
             - `props`: The properties of the current flow, which could contain
             properties that were added to the `props` dictionary
             in the serve op before this update op. Props are short-lived and
-            die after the dataflow's update op finishes.
+            die after the flow's update op finishes.
 
         Components can have multiple update ops, and the same key can also have
         multiple update ops. Update functions should return a dictionary
         of state updates to be merged with the current state.
 
+        See `DiscardPolicy` for more info on how to expire update operations if
+        you expect there to be backpressure for an update operation.
+
         Example Usage:
         ```python
         from motion import Component
@@ -433,7 +447,12 @@ class Component:
 
         Args:
             keys (Union[str, List[str]]): String or list of strings that
-                represent the input keyword(s) for the update dataflow.
+                represent the input keyword(s) for the update flow.
+            discard_policy (DiscardPolicy, optional): Policy for expiring
+                update operations. Defaults to DiscardPolicy.NONE.
+            discard_after (Optional[int], optional): Number of updates
+                or seconds after which to expire the update operation.
+                Defaults to None.
 
         Returns:
             Callable: Decorated update function.
@@ -455,9 +474,12 @@ class Component:
                     + "`state` and `props`."
                 )
 
-            # func._input_key = key  # type: ignore
-            # func._batch_size = batch_size  # type: ignore
+            # Raises error if invalid expire policy
+            validate_policy(discard_policy, discard_after)
+
             func._op = "update"  # type: ignore
+            func._discard_policy = discard_policy  # type: ignore
+            func._discard_after = discard_after  # type: ignore
 
             for key in keys:
                 self.add_route(key, func._op, func)  # type: ignore
@@ -474,6 +496,7 @@ class Component:
         update_task_type: Literal["thread", "process"] = "thread",
         disable_update_task: bool = False,
         redis_socket_timeout: int = 60,
+        config_path: str = ".motionrc.yml",
     ) -> ComponentInstance:
         """Creates and returns a new instance of a Motion component.
         See `ComponentInstance` docs for more info.
@@ -499,9 +522,13 @@ class Component:
         if __name__ == "__main__":
             c_instance = MyComponent(init_state_params={"starting_val": 3})
             c_instance.run(..)
+            c_instance.shutdown()
         ```
 
-        You can also use component instances as context managers:
+        You can also use component instances as context managers,
+        which is the recommended way to use them (because it will
+        automatically gracefully shut down the component instance
+        when the context manager exits):
         ```python
         ...
         if __name__ == "__main__":
@@ -526,13 +553,15 @@ class Component:
                 but has higher startup overhead. Defaults to "thread".
             disable_update_task (bool, optional):
                 Whether or not to disable the component instance update ops.
-                Useful for printing out state values without running dataflows.
+                Useful for printing out state values without running flows.
                 Defaults to False.
             redis_socket_timeout (int, optional):
                 Timeout for redis socket connections (seconds). Defaults to 60.
                 This means the redis connection will close if idle for 60 seconds.
+            config_path (str, optional):
+                Path to config file of env vars. Defaults to ".motionrc.yml".
         Returns:
-            ComponentInstance: Component instance to run dataflows with.
+            ComponentInstance: Component instance to run flows with.
         """
         if not instance_id:
             instance_id = random_passphrase()
@@ -543,6 +572,37 @@ class Component:
                 + "name from your instance id."
             )
 
+        import_config(config_path)
+
+        # Register cleanup hook if in dev mode
+        # Set up an atexit hook to clear all instances in dev mode
+
+        if os.getenv("MOTION_ENV", "prod") == "dev":
+            if not os.getenv("CLEANUP_DEV_REGISTERED"):
+                import atexit
+
+                from rich.console import Console
+
+                def cleanup_dev() -> None:
+                    # Print cleanup message with rich spinner
+                    console = Console()
+                    with console.status(
+                        "[bold green]Performing cleanup...[/bold green]", spinner="dots"
+                    ):
+                        num_deleted = clear_dev_instances()
+
+                    plural = "s" if num_deleted != 1 else ""
+                    console.print(
+                        "[bold green]Cleanup finished successfully! "
+                        + f"Deleted {num_deleted} instance{plural}.[/bold green]"
+                    )
+
+                # Register the cleanup function
+                atexit.register(cleanup_dev)
+
+                # Set the env var to True
+                os.environ["CLEANUP_DEV_REGISTERED"] = "True"
+
         try:
             ci = ComponentInstance(
                 component_name=self.name,
